stringtools.is_underscore_delimited_lowercase_file_name_with_extension
======================================================================

.. autofunction:: abjad.tools.stringtools.is_underscore_delimited_lowercase_file_name_with_extension.is_underscore_delimited_lowercase_file_name_with_extension
   :noindex:
